@@ -1,4 +1,4 @@
-# Copyright (C) 2008, Sebastian Riedel.
+# Copyright (C) 2008-2009, Sebastian Riedel.
 
 package Mojo::Script::DaemonPrefork;
 
@@ -9,7 +9,7 @@ use base 'Mojo::Script';
 
 use Mojo::Server::Daemon::Prefork;
 
-__PACKAGE__->attr('description', chained => 1, default => <<'EOF');
+__PACKAGE__->attr(description => (chained => 1, default => <<'EOF'));
 * Start the prefork daemon. *
 Takes a port as option, by default 3000 will be used.
     daemon_prefork
@@ -40,12 +40,13 @@ Mojo::Script::DaemonPrefork - Prefork Daemon Script
 =head1 SYNOPSIS
 
     use Mojo::Script::Daemon::Prefork;
+
     my $daemon = Mojo::Script::Daemon::Prefork->new;
     $daemon->run(@ARGV);
 
 =head1 DESCRIPTION
 
-L<Mojo::Script::Daemon::Prefork> is a simple script interface to
+L<Mojo::Script::Daemon::Prefork> is a script interface to
 L<Mojo::Server::Daemon::Prefork>.
 
 =head1 ATTRIBUTES
@@ -67,4 +68,4 @@ and implements the following new ones.
 
     $daemon = $daemon->run(@ARGV);
 
-=cut
\ No newline at end of file
+=cut
