@@ -1,4 +1,4 @@
-# Copyright (C) 2008, Sebastian Riedel.
+# Copyright (C) 2008-2009, Sebastian Riedel.
 
 package Mojo::Script::Test;
 
@@ -12,7 +12,7 @@ use FindBin;
 use File::Spec;
 use Test::Harness;
 
-__PACKAGE__->attr('description', chained => 1, default => <<'EOF');
+__PACKAGE__->attr(description => (chained => 1, default => <<'EOF'));
 * Run unit tests. *
 Takes a list of tests as options, by default it will try to detect a 't'
 directory.
@@ -27,6 +27,7 @@ sub run {
     # Search tests
     unless (@tests) {
         my @base = File::Spec->splitdir(File::Spec->abs2rel($FindBin::Bin));
+
         # Test directory in the same directory as "mojo" (t)
         my $path = File::Spec->catdir(@base, 't');
 
@@ -46,9 +47,12 @@ sub run {
                 next if $file eq '..';
                 my $fpath = File::Spec->catfile($dir, $file);
                 push @dirs, File::Spec->catdir($dir, $file) if -d $fpath;
-                push @tests, File::Spec->abs2rel(Cwd::realpath(
-                    File::Spec->catfile(File::Spec->splitdir($fpath))
-                )) if (-f $fpath) && ($fpath =~ /\.t$/);
+                push @tests,
+                  File::Spec->abs2rel(
+                    Cwd::realpath(
+                        File::Spec->catfile(File::Spec->splitdir($fpath))
+                    )
+                  ) if (-f $fpath) && ($fpath =~ /\.t$/);
             }
             closedir $fh;
         }
@@ -100,4 +104,4 @@ implements the following new ones.
 
     $test = $test->run(@ARGV);
 
-=cut
\ No newline at end of file
+=cut
