@@ -1,4 +1,4 @@
-# Copyright (C) 2008, Sebastian Riedel.
+# Copyright (C) 2008-2009, Sebastian Riedel.
 
 package MojoliciousTest::Foo;
 
@@ -27,4 +27,9 @@ sub test {
     $c->res->body($c->url_for(controller => 'bar'));
 }
 
+sub willdie {
+    my $self = shift;
+    die 'for some reason';
+}
+
 1;
